@@ -32,14 +32,6 @@ class SwitchRelayOffMessage(Message):
         self.set_attributes(priority, address, rtr)
         self.relay_channels = self.byte_to_channels(data[0])
 
-    def to_json(self):
-        """
-        :return: str
-        """
-        json_dict = self.to_json_basic()
-        json_dict["channels"] = self.relay_channels
-        return json.dumps(json_dict)
-
     def set_defaults(self, address):
         if address is not None:
             self.set_address(address)
