@@ -28,13 +28,6 @@ class TempSetHeatingMessage(Message):
         self.needs_no_rtr(rtr)
         self.set_attributes(priority, address, rtr)
 
-    def to_json(self):
-        """
-        :return: str
-        """
-        json_dict = self.to_json_basic()
-        return json.dumps(json_dict)
-
     def data_to_binary(self):
         """
         :return: bytes
